Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1340)

Unified Diff: cc/input/scrollbar_animation_controller.cc

Issue 2753933005: cc: Move Layer Id to Node Map to Individual Property Tree Private (Closed)
Patch Set: renaming clean up Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | cc/layers/layer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/input/scrollbar_animation_controller.cc
diff --git a/cc/input/scrollbar_animation_controller.cc b/cc/input/scrollbar_animation_controller.cc
index 4906ef4737db1921018b018ad1b8243652714805..b72b487e0cf7355300c8b354082cbd7a3b491647 100644
--- a/cc/input/scrollbar_animation_controller.cc
+++ b/cc/input/scrollbar_animation_controller.cc
@@ -346,15 +346,17 @@ void ScrollbarAnimationController::ApplyOpacityToScrollbars(float opacity) {
PropertyTrees* property_trees =
scrollbar->layer_tree_impl()->property_trees();
// If this method is called during LayerImpl::PushPropertiesTo, we may not
- // yet have valid layer_id_to_effect_node_index entries as property trees
- // are pushed after layers during activation. We can skip updating opacity
- // in that case as we are only registering a scrollbar and because opacity
- // will be overwritten anyway when property trees are pushed.
- if (property_trees->IsInIdToIndexMap(PropertyTrees::TreeType::EFFECT,
- scrollbar->id())) {
+ // yet have valid owning_layer_id_to_node_index entries in effect tree as
+ // property trees are pushed after layers during activation. We can skip
+ // updating opacity in that case as we are only registering a scrollbar and
+ // because opacity will be overwritten anyway when property trees are
+ // pushed.
+ if (property_trees->effect_tree.FindNodeIndexFromOwningLayerId(
+ scrollbar->id()) != EffectTree::kInvalidNodeId) {
property_trees->effect_tree.OnOpacityAnimated(
effective_opacity,
- property_trees->layer_id_to_effect_node_index[scrollbar->id()],
+ property_trees->effect_tree.FindNodeIndexFromOwningLayerId(
+ scrollbar->id()),
scrollbar->layer_tree_impl());
}
}
« no previous file with comments | « no previous file | cc/layers/layer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698